@@ -49,13 +49,21 @@ void BluetoothDeviceModel::updateData(BluetoothDevice *device)
     for (int index = 0; index < m_deviceData.count(); index++) {
         const BluetoothDevice *item = m_deviceData.at(index);
         if (item->id() == device->id()) {
-            QModelIndex modelIndex = createIndex(index, 0);
-            emit dataChanged(modelIndex, modelIndex, {});
+            bool isConnected = (device->state() == BluetoothDevice::StateConnected && device->connectState());
+            if (isConnected && index > 0) {
+                moveToTop(device->id());
+            } else if (!isConnected) {
+                reorderDevices();
+            } else {
+                QModelIndex modelIndex = createIndex(index, 0);
+                emit dataChanged(modelIndex, modelIndex, {});
+            }
             return;
         }
     }
     qDebug() << " updateAdapter new device : " << device->id();
     addDevice(device);
+    reorderDevices();
 }
 
 void BluetoothDeviceModel::updateAllData()
@@ -66,6 +74,47 @@ void BluetoothDeviceModel::updateAllData()
     }
 }
 
+void BluetoothDeviceModel::moveToTop(const QString &deviceId)
+{
+    int currentIndex = deviceIndex(deviceId);
+    if (currentIndex <= 0) {
+        return;
+    }
+    
+    beginMoveRows(QModelIndex(), currentIndex, currentIndex, QModelIndex(), 0);
+    BluetoothDevice* device = m_deviceData.takeAt(currentIndex);
+    m_deviceData.prepend(device);
+    endMoveRows();
+}
+
+void BluetoothDeviceModel::reorderDevices()
+{
+    QList<BluetoothDevice*> connectedDevices;
+    QList<BluetoothDevice*> disconnectedDevices;
+    
+    for (int i = 0; i < m_deviceData.count(); i++) {
+        BluetoothDevice* device = m_deviceData.at(i);
+        if (device->state() == BluetoothDevice::StateConnected && device->connectState()) {
+            connectedDevices.append(device);
+        } else {
+            disconnectedDevices.append(device);
+        }
+    }
+    
+    if (connectedDevices.isEmpty() || disconnectedDevices.isEmpty()) {
+        updateAllData();
+        return;
+    }
+    
+    beginResetModel();
+    
+    m_deviceData.clear();
+    m_deviceData.append(connectedDevices);
+    m_deviceData.append(disconnectedDevices);
+    
+    endResetModel();
+}
+
 int BluetoothDeviceModel::rowCount(const QModelIndex &parent) const
 {
     // For list models only the root node (an invalid parent) should return the list's size. For all
