@@ -11,6 +11,7 @@ class DisplayWorker;
 class DisplayModel;
 class DisplayModule;
 class DccScreen;
+class ScreenData;
 
 class DisplayModulePrivate
 {
@@ -25,8 +26,10 @@ public:
     void updateMonitorList();
     void updatePrimary();
     void updateDisplayMode();
+    void updateMaxGlobalScale();
     DccScreen *primary() const;
     QString displayMode() const;
+    void setScreenPosition(QList<ScreenData *> screensData);
 
 public:
     DisplayModule *q_ptr;
@@ -36,6 +39,7 @@ public:
     QList<DccScreen *> m_virtualScreens;
     DccScreen *m_primary;
     QString m_displayMode;
+    qreal m_maxGlobalScale;
 
     Q_DECLARE_PUBLIC(DisplayModule)
 };
