@@ -83,9 +83,6 @@ bool WallpaperModel::setData(const QModelIndex &index, const QVariant &value, in
             Q_EMIT dataChanged(index, index, {role});
 
         }
-    } else if (role == Item_Thumbnail_Role) {
-        items[index.row()]->thumbnail = value.toString();
-        Q_EMIT dataChanged(index, index, {role});
     }
 
     return QAbstractItemModel::setData(index, value, role);
@@ -179,16 +176,6 @@ void WallpaperModel::updateSelected(const QStringList &selectedLists)
     }
 }
 
-void WallpaperModel::setThumbnail(WallpaperItemPtr item, const QString &thumbnail)
-{
-    for (int i = 0; i < items.size(); ++i) {
-        if (items[i].get() == item.get()) {
-            setData(index(i, 0), thumbnail, Item_Thumbnail_Role);
-            break;
-        }
-    }
-}
-
 QString WallpaperSortModel::getPicPathByUrl(const QString &url) const
 {
     for(int i = 0; i < sourceModel()->rowCount(); i++) {
