@@ -7,8 +7,8 @@
 #include "powerdbusproxy.h"
 #include <QObject>
 #include <DConfig>
+#include "powermodel.h"
 
-class PowerModel;
 class PowerWorker : public QObject
 {
     Q_OBJECT
@@ -21,6 +21,10 @@ public:
 
 public Q_SLOTS:
     void setScreenBlackLock(const bool lock);
+    void setScheduledShutdownState(const bool state);
+    void setShutdownTime(const QString &time);
+    void setShutdownRepetition(int repetition);
+    void setCustomShutdownWeekDays(const QString &weekdays);
     void setSleepLock(const bool lock);
     void setSleepOnLidOnPowerClosed(const bool sleep);
     void setSleepDelayOnPower(const int delay);
@@ -49,6 +53,7 @@ public Q_SLOTS:
     void setLowPowerNotifyEnable(bool bLowPowerNotifyEnable);
     void setLowPowerNotifyThreshold(int dLowPowerNotifyThreshold);
     void setLowPowerAutoSleepThreshold(int dLowPowerAutoSleepThreshold);
+    void setLowPowerAction(int action);
     //------------------------------------------
     void setPowerPlan(const QString &powerPlan);
     void setShowBatteryTimeToFull(bool value);
@@ -63,7 +68,10 @@ public Q_SLOTS:
 private:
     void readConfig(const QString &key, std::function<void(const QVariantList &value)> callback);
     void readConfig(const QString &key, std::function<void(const bool value)> callback);
+    void readConfig(const QString &key, std::function<void(const QString &value)> callback);
     QVariantList converToDataMap(const QStringList& conf);
+private slots:
+    void onCustomShutdownWeekDaysChanged(const QByteArray &value);
 
 private:
     PowerModel *m_powerModel;
@@ -71,6 +79,7 @@ private:
 
     Dtk::Core::DConfig *m_cfgDock;
     Dtk::Core::DConfig *m_cfgPower;
+    Dtk::Core::DConfig *m_cfgTime;
 };
 
 #endif // POWERWORKER_H
